==> dl.php?src=linea21_1_0.zip: linea21/theme/sup.php <==
<?
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

include_once("../lib/lib_common.php"); 

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

$mask_mass_del="style=\"visibility:hidden;\"";
$mask_mass_mod="style=\"visibility:hidden;\"";
$mask_del_meth='';
$mask_mod_meth='';
$form_theme_transfert=-1;

if(isset($_POST['valider'])) {
	$integrity=1;
	if(isset($_POST['sup_method'])) {
		$sup_method=$_POST['sup_method'];
		if($sup_method=='delete') {
			$type='MASS_DELETE';
			$mask_mass_del="style=\"visibility:visible;\"";
			$mask_del_meth="checked=\"checked\"";
			$form_theme_transfert=-1;
		}
		if($sup_method=='modify') {
			$type='MASS_MODIFY';
			$mask_mod_meth="checked=\"checked\"";
			$mask_mass_mod="style=\"visibility:visible;;\"";
			if($_POST['transfert_theme']==-1) $integrity=$GLOBALS['lang']['theme']['sup_notheme'];
			else $form_theme_transfert=$_POST['transfert_theme'];
		}
		if($_SESSION['securityaction']!=md5($_POST['securitycode'])) {
			$integrity=$GLOBALS['lang']['security']['message'];
		}
		if(!is_string($integrity)) {
			$theme_object= new theme;
			$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
			$result=$theme_object->DeleteTheme($id, $sql_object, $type, $form_theme_transfert);
			if(is_numeric($result)) header("Location: ".$link_confirm);
			else  system_error();
		}
	}	else  {
		$integrity=$GLOBALS['lang']['theme']['sup_nomethod'];
	}

}


include_once("../lib/select_box.php");
$req_list=SQL_getlist4sup($id);
$data=$sql_object->DBSelect($req_list);
// select-box des thmes
$select_theme=ThemeSelectBox($data, "transfert_theme", $form_theme_transfert);

$req_det= SQL_getonetheme($id);
$result1=$sql_object->DBSelect($req_det);
$theme_name=formatText($result1[0]['theme_name'],'2HTML');

?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['theme']?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($theme_name); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>
<? echo "<h2>".formatTitleh2($theme_name)."</h2>"; ?>
<form id="suptheme" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<p>
	<input type="radio" name="sup_method" id="sup_method_del" value="delete" onclick="ShowSuppInfo('mass_delete');" <?php echo $mask_del_meth; ?>/> 
	<? echo $GLOBALS['lang']['theme']['sup_massd']; ?>
</p>
<p>
	<input type="radio" name="sup_method" id="sup_method_mod" value="modify" onclick="ShowSuppInfo('mass_modify');" <?php echo $mask_mod_meth; ?>/>
	<? echo $GLOBALS['lang']['theme']['sup_massm']; ?>
</p>
<p id="transfert" <? echo $mask_mass_mod; ?>>
	<label for="transfert_theme" ><? echo $GLOBALS['lang']['theme']['sup_transfert']; ?></label>
	<?php echo $select_theme; ?>
</p>
<p>
	<label for="securitycode" ><? echo $GLOBALS['lang']['security']['info']; ?></label>
	<img src="securitycode.php" alt="<? echo $GLOBALS['lang']['security']['info2']; ?>" id="securityimg" />
	<input type="text" class="shorttextfield" id="securitycode" maxlength="5" name="securitycode" />  
</p>
<?php
echo "<div class=\"info\"  id=\"mass_delete\" ".$mask_mass_del.">\n";
echo "\t".$GLOBALS['lang']['theme']['sup_mass_delete']."\n";
echo "</div>\n";
echo "<div class=\"info\" id=\"mass_modify\" ".$mask_mass_mod.">\n";
echo "\t".$GLOBALS['lang']['theme']['sup_mass_modify']."\n";
echo "</div>\n";
?>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<?php echo cancel_button('javascript:history.go(-1);'); ?>
<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>

==> dl.php?src=linea21_1_1.zip: linea21/theme/sup.php <==
<?
//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

include_once("../lib/lib_common.php"); 

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

$mask_mass_del="style=\"visibility:hidden;\"";
$mask_mass_mod="style=\"visibility:hidden;\"";
$mask_del_meth='';
$mask_mod_meth='';
$form_theme_transfert=-1;

if(isset($_POST['valider'])) {
	$integrity=1;
	if(isset($_POST['sup_method'])) {
		$sup_method=$_POST['sup_method'];
		if($sup_method=='delete') {
			$type='MASS_DELETE';
			$mask_mass_del="style=\"visibility:visible;\"";
			$mask_del_meth="checked=\"checked\"";
			$form_theme_transfert=-1;
		}
		if($sup_method=='modify') {
			$type='MASS_MODIFY';
			$mask_mod_meth="checked=\"checked\"";
			$mask_mass_mod="style=\"visibility:visible;;\"";
			if($_POST['transfert_theme']==-1) $integrity=$GLOBALS['lang']['theme']['sup_notheme'];
			else $form_theme_transfert=$_POST['transfert_theme'];
		}
		if($_SESSION['securityaction']!=md5($_POST['securitycode'])) {
			$integrity=$GLOBALS['lang']['security']['message'];
		}
		if(!is_string($integrity)) {
			$theme_object= new theme;
			$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
			$result=$theme_object->DeleteTheme($id, $sql_object, $type, $form_theme_transfert);
			if(is_numeric($result)) header("Location: ".$link_confirm);
			else  system_error();
		}
	}	else  {
		$integrity=$GLOBALS['lang']['theme']['sup_nomethod'];
	}

}


include_once("../lib/select_box.php");
$req_list=SQL_getlist4sup($id);
$data=$sql_object->DBSelect($req_list);
// select-box des thèmes
$select_theme=ThemeSelectBox($data, "transfert_theme", $form_theme_transfert);

$req_det= SQL_getonetheme($id);
$result1=$sql_object->DBSelect($req_det);
$theme_name=formatText($result1[0]['theme_name'],'2HTML');

?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['theme']?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($theme_name); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>
<? echo "<h2>".formatTitleh2($theme_name)."</h2>"; ?>
<form id="suptheme" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<p>
	<input type="radio" name="sup_method" id="sup_method_del" value="delete" onclick="ShowSuppInfo('mass_delete');" <?php echo $mask_del_meth; ?>/> 
	<? echo $GLOBALS['lang']['theme']['sup_massd']; ?>
</p>
<p>
	<input type="radio" name="sup_method" id="sup_method_mod" value="modify" onclick="ShowSuppInfo('mass_modify');" <?php echo $mask_mod_meth; ?>/>
	<? echo $GLOBALS['lang']['theme']['sup_massm']; ?>
</p>
<p id="transfert" <? echo $mask_mass_mod; ?>>
	<label for="transfert_theme" ><? echo $GLOBALS['lang']['theme']['sup_transfert']; ?></label>
	<?php echo $select_theme; ?>
</p>
<p>
	<label for="securitycode" ><? echo $GLOBALS['lang']['security']['info']; ?></label>
	<img src="securitycode.php" alt="<? echo $GLOBALS['lang']['security']['info2']; ?>" id="securityimg" />
	<input type="text" class="shorttextfield" id="securitycode" maxlength="5" name="securitycode" />  
</p>
<?php
echo "<div class=\"info\"  id=\"mass_delete\" ".$mask_mass_del.">\n";
echo "\t".$GLOBALS['lang']['theme']['sup_mass_delete']."\n";
echo "</div>\n";
echo "<div class=\"info\" id=\"mass_modify\" ".$mask_mass_mod.">\n";
echo "\t".$GLOBALS['lang']['theme']['sup_mass_modify']."\n";
echo "</div>\n";
?>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<?php echo cancel_button('javascript:history.go(-1);'); ?>
<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>
